@@ -1,5 +1,5 @@
 /* Arg_parser - POSIX/GNU command line argument parser. (C version)
-   Copyright (C) 2006-2021 Antonio Diaz Diaz.
+   Copyright (C) 2006-2022 Antonio Diaz Diaz.
 
    This program is free software: you have unlimited permission to
    copy, distribute, and modify it.
@@ -12,9 +12,10 @@
    Exit status: 0 for a normal exit, 1 for environmental problems
    (file not found, invalid flags, I/O errors, etc), 2 to indicate a
    corrupt or invalid input file, 3 for an internal consistency error
-   (eg, bug) which caused arg_parser to panic.
+   (e.g., bug) which caused carg_parser to panic.
 */
 
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -22,12 +23,12 @@
 #include "carg_parser.h"
 
 
-static const char * const program_name = "arg_parser";
-static const char * const program_year = "2021";
-static const char * invocation_name = "arg_parser";	/* default value */
+static const char * const program_name = "carg_parser";
+static const char * const program_year = "2022";
+static const char * invocation_name = "carg_parser";	/* default value */
 
 
-void show_help( const char verbose )
+static void show_help( const char verbose )
   {
   printf( "Arg_parser - POSIX/GNU command line argument parser. (C version)\n"
           "\nArg_parser is an argument parser that follows POSIX and GNU conventions for\n"
@@ -58,15 +59,13 @@ void show_help( const char verbose )
           "  -u, --uncaught               example of intentional bug\n"
           "  -v, --verbose                verbose operation\n" );
   if( verbose )
-    {
     printf( "  -H, --hidden                 example of hidden option (shown with -v -h)\n" );
-    }
   printf( "\nReport bugs to arg-parser-bug@nongnu.org\n"
           "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
   }
 
 
-void show_version()
+static void show_version()
   {
   printf( "%s %s\n", program_name, PROGVERSION );
   printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
@@ -76,7 +75,8 @@ void show_version()
   }
 
 
-void show_error( const char * const msg, const int errcode, const char help )
+static void show_error( const char * const msg, const int errcode,
+                        const char help )
   {
   if( msg && msg[0] )
     fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
@@ -88,27 +88,13 @@ void show_error( const char * const msg, const int errcode, const char help )
   }
 
 
-void internal_error( const char * const msg )
+static void internal_error( const char * const msg )
   {
   fprintf( stderr, "%s: internal error: %s\n", program_name, msg );
   exit( 3 );
   }
 
 
-const char * optname( const int code, const struct ap_Option options[] )
-  {
-  static char buf[2] = "?";
-  int i;
-
-  if( code != 0 )
-    for( i = 0; options[i].code; ++i )
-      if( code == options[i].code )
-        { if( options[i].name ) return options[i].name; else break; }
-  if( code > 0 && code < 256 ) buf[0] = code; else buf[0] = '?';
-  return buf;
-  }
-
-
 int main( const int argc, const char * const argv[] )
   {
   char verbose = 0;
@@ -125,6 +111,8 @@ int main( const int argc, const char * const argv[] )
     { 'v', "verbose",  ap_no    },
     { 'V', "version",  ap_no    },
     { 256, "orphan",   ap_no    },
+    { INT_MIN, "int-min", ap_no },
+    { INT_MAX, "int-max", ap_no },
     {   0, 0,          ap_no    } };
 
   struct Arg_parser parser;
@@ -153,6 +141,8 @@ int main( const int argc, const char * const argv[] )
       case 'v': verbose = 1; break;
       case 'V': show_version(); return 0;
       case 256: break;				/* example, do nothing */
+      case INT_MIN: break;			/* example, do nothing */
+      case INT_MAX: break;			/* example, do nothing */
       default : internal_error( "uncaught option." );
       }
     } /* end process options */
@@ -163,13 +153,9 @@ int main( const int argc, const char * const argv[] )
     const char * const arg = ap_argument( &parser, argind );
     if( code )	/* option */
       {
-      const char * const name = optname( code, options );
-      if( !name[1] )
-        printf( "option '-%c'", name[0] );
-      else
-        printf( "option '--%s'", name );
-      if( arg[0] )
-        printf( " with argument '%s'", arg );
+      printf( "option '%s'", ap_parsed_name( &parser, argind ) );
+      if( arg[0] ) printf( " with argument '%s'", arg );
+      if( code == INT_MIN || code == INT_MAX ) printf( " (code 0x%X)", code );
       }
     else	/* non-option */
       printf( "non-option argument '%s'", arg );
@@ -178,5 +164,6 @@ int main( const int argc, const char * const argv[] )
 
   if( !ap_arguments( &parser ) ) fputs( "Hello, world!\n", stdout );
 
+  ap_free( &parser );
   return 0;
   }
