@@ -1,5 +1,5 @@
 /* Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-   Copyright (C) 2006-2021 Antonio Diaz Diaz.
+   Copyright (C) 2006-2022 Antonio Diaz Diaz.
 
    This program is free software: you have unlimited permission to
    copy, distribute, and modify it.
@@ -12,9 +12,10 @@
    Exit status: 0 for a normal exit, 1 for environmental problems
    (file not found, invalid flags, I/O errors, etc), 2 to indicate a
    corrupt or invalid input file, 3 for an internal consistency error
-   (eg, bug) which caused arg_parser to panic.
+   (e.g., bug) which caused arg_parser to panic.
 */
 
+#include <climits>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
@@ -27,7 +28,7 @@
 namespace {
 
 const char * const program_name = "arg_parser";
-const char * const program_year = "2021";
+const char * const program_year = "2022";
 const char * invocation_name = program_name;		// default value
 
 
@@ -62,9 +63,7 @@ void show_help( const bool verbose )
                "  -u, --uncaught               example of intentional bug\n"
                "  -v, --verbose                verbose operation\n" );
   if( verbose )
-    {
     std::printf( "  -H, --hidden                 example of hidden option (shown with -v -h)\n" );
-    }
   std::printf( "\nReport bugs to arg-parser-bug@nongnu.org\n"
                "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
   }
@@ -99,19 +98,6 @@ void internal_error( const char * const msg )
   std::exit( 3 );
   }
 
-
-const char * optname( const int code, const Arg_parser::Option options[] )
-  {
-  static char buf[2] = "?";
-
-  if( code != 0 )
-    for( int i = 0; options[i].code; ++i )
-      if( code == options[i].code )
-        { if( options[i].name ) return options[i].name; else break; }
-  if( code > 0 && code < 256 ) buf[0] = code; else buf[0] = '?';
-  return buf;
-  }
-
 } // end namespace
 
 
@@ -133,6 +119,8 @@ int main( const int argc, const char * const argv[] )
     { 'v', "verbose",  Arg_parser::no    },
     { 'V', "version",  Arg_parser::no    },
     { 256, "orphan",   Arg_parser::no    },
+    { INT_MIN, "int-min", Arg_parser::no },
+    { INT_MAX, "int-max", Arg_parser::no },
     {   0, 0,          Arg_parser::no    } };
 
   const Arg_parser parser( argc, argv, options );
@@ -156,6 +144,8 @@ int main( const int argc, const char * const argv[] )
       case 'v': verbose = true; break;
       case 'V': show_version(); return 0;
       case 256: break;				// example, do nothing
+      case INT_MIN: break;			// example, do nothing
+      case INT_MAX: break;			// example, do nothing
       default : internal_error( "uncaught option." );
       }
     } // end process options
@@ -166,13 +156,9 @@ int main( const int argc, const char * const argv[] )
     const char * const arg = parser.argument( argind ).c_str();
     if( code )	// option
       {
-      const char * const name = optname( code, options );
-      if( !name[1] )
-        std::printf( "option '-%c'", name[0] );
-      else
-        std::printf( "option '--%s'", name );
-      if( arg[0] )
-        std::printf( " with argument '%s'", arg );
+      std::printf( "option '%s'", parser.parsed_name( argind ).c_str() );
+      if( arg[0] ) std::printf( " with argument '%s'", arg );
+      if( code == INT_MIN || code == INT_MAX ) std::printf( " (code 0x%X)", code );
       }
     else	// non-option
       std::printf( "non-option argument '%s'", arg );
