@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Arg_parser - POSIX/GNU command line argument parser.
-# Copyright (C) 2011-2021 Antonio Diaz Diaz.
+# Copyright (C) 2011-2022 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -40,23 +40,27 @@ for i in "${PARSER}" "${CPARSER}" ; do
 	"$i" -h -v > /dev/null || test_failed $LINENO "$i"
 	"$i" -v -h > /dev/null || test_failed $LINENO "$i"
 
-	"$i" -a -b 5 -c -carg -o file --orphan --verbose file1 file2 > out ||
+	"$i" --append -a -b 5 --block 10 -c -carg --casual --casual=arg -o file --orphan --verbose file1 file2 > out ||
 		test_failed $LINENO "$i"
 	cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" -ab5 -c -carg -ofile file1 --orphan file2 --verbos > out ||
+	"$i" file1 file2 --append -ab5 --block=10 -c -carg --casua --casua=arg -ofile --orpha --verbos > out ||
 		test_failed $LINENO "$i"
 	cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" --append file1 --block 5 --casual file2 --casual=arg -o file --orphan --verbo > out ||
+	"$i" --append -a file1 -b 5 --block 10 -c -carg --casu --casu=arg -o file file2 --orph --verbo > out ||
 		test_failed $LINENO "$i"
 	cmp "${in}" out || test_failed $LINENO "$i"
 
-	"$i" --append --block=5 --casual= file1 --casual=arg -ofile --orphan --verb file2 > out ||
+	"$i" --append -a -b5 --block=10 -c -carg --cas= file1 --cas=arg -ofile --orp --verb file2 > out ||
 		test_failed $LINENO "$i"
 	cmp "${in}" out || test_failed $LINENO "$i"
 done
 
+"${PARSER}" --int-min --int-max > out || test_failed $LINENO
+"${CPARSER}" --int-min --int-max > cout || test_failed $LINENO
+cmp out cout || test_failed $LINENO
+
 printf "\ntesting bad input..."
 
 for i in "${PARSER}" "${CPARSER}" ; do
